"""
Tests
"""

from typing import Callable

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.countries_names_resolvers.medalists_resolvers import resolve_countries_names_medalists

main_data = {
    "universiade competitors": "منافسون في الألعاب الجامعية",
    "universiade medalists": "فائزون بميداليات الألعاب الجامعية",
    "commonwealth games gold medalists": "فائزون بميداليات ذهبية في ألعاب الكومنولث",
    "Olympic gold medalists for Papua New Guinea": "فائزون بميداليات ذهبية أولمبية من بابوا غينيا الجديدة",
    "Olympic gold medalists for the United States in alpine skiing": "فائزون بميداليات ذهبية أولمبية من الولايات المتحدة في التزلج على المنحدرات الثلجية",
    "Olympic gold medalists for the United States": "فائزون بميداليات ذهبية أولمبية من الولايات المتحدة",
    "islamic solidarity games silver medalists": "فائزون بميداليات فضية في ألعاب التضامن الإسلامي",
    "summer islamic solidarity games medalists": "فائزون بميداليات ألعاب التضامن الإسلامي الصيفية",
}

summer_winter_tabs = {
    "african games bids": "عروض الألعاب الإفريقية",
    "african games competitions": "منافسات الألعاب الإفريقية",
    "african games events": "أحداث الألعاب الإفريقية",
    "african games festival": "مهرجانات الألعاب الإفريقية",
    "african games templates": "قوالب الألعاب الإفريقية",
    "all-africa games bids": "عروض ألعاب عموم إفريقيا",
    "all-africa games competitions": "منافسات ألعاب عموم إفريقيا",
    "all-africa games events": "أحداث ألعاب عموم إفريقيا",
    "all-africa games festival": "مهرجانات ألعاب عموم إفريقيا",
    "all-africa games templates": "قوالب ألعاب عموم إفريقيا",
    "asian beach games bids": "عروض دورة الألعاب الآسيوية الشاطئية",
    "asian beach games competitions": "منافسات دورة الألعاب الآسيوية الشاطئية",
    "asian beach games events": "أحداث دورة الألعاب الآسيوية الشاطئية",
    "asian beach games festival": "مهرجانات دورة الألعاب الآسيوية الشاطئية",
    "asian beach games templates": "قوالب دورة الألعاب الآسيوية الشاطئية",
    "asian games bids": "عروض الألعاب الآسيوية",
    "asian games competitions": "منافسات الألعاب الآسيوية",
    "asian games events": "أحداث الألعاب الآسيوية",
    "asian games festival": "مهرجانات الألعاب الآسيوية",
    "asian games templates": "قوالب الألعاب الآسيوية",
    "asian indoor games bids": "عروض دورة الألعاب الآسيوية داخل الصالات",
    "asian indoor games competitions": "منافسات دورة الألعاب الآسيوية داخل الصالات",
    "asian indoor games events": "أحداث دورة الألعاب الآسيوية داخل الصالات",
    "asian indoor games festival": "مهرجانات دورة الألعاب الآسيوية داخل الصالات",
    "asian indoor games templates": "قوالب دورة الألعاب الآسيوية داخل الصالات",
    "asian para games bids": "عروض الألعاب البارالمبية الآسيوية",
    "asian para games competitions": "منافسات الألعاب البارالمبية الآسيوية",
    "asian para games events": "أحداث الألعاب البارالمبية الآسيوية",
    "asian para games festival": "مهرجانات الألعاب البارالمبية الآسيوية",
    "asian para games templates": "قوالب الألعاب البارالمبية الآسيوية",
    "asian summer games bids": "عروض الألعاب الآسيوية الصيفية",
    "asian summer games competitions": "منافسات الألعاب الآسيوية الصيفية",
    "asian summer games events": "أحداث الألعاب الآسيوية الصيفية",
    "asian summer games festival": "مهرجانات الألعاب الآسيوية الصيفية",
    "asian summer games templates": "قوالب الألعاب الآسيوية الصيفية",
    "asian winter games bids": "عروض الألعاب الآسيوية الشتوية",
    "asian winter games competitions": "منافسات الألعاب الآسيوية الشتوية",
    "asian winter games events": "أحداث الألعاب الآسيوية الشتوية",
    "asian winter games festival": "مهرجانات الألعاب الآسيوية الشتوية",
    "asian winter games templates": "قوالب الألعاب الآسيوية الشتوية",
    "bolivarian games bids": "عروض الألعاب البوليفارية",
    "bolivarian games competitions": "منافسات الألعاب البوليفارية",
    "bolivarian games events": "أحداث الألعاب البوليفارية",
    "bolivarian games festival": "مهرجانات الألعاب البوليفارية",
    "bolivarian games templates": "قوالب الألعاب البوليفارية",
    "central american and caribbean games bids": "عروض ألعاب أمريكا الوسطى والكاريبي",
    "central american and caribbean games competitions": "منافسات ألعاب أمريكا الوسطى والكاريبي",
    "central american and caribbean games events": "أحداث ألعاب أمريكا الوسطى والكاريبي",
    "central american and caribbean games festival": "مهرجانات ألعاب أمريكا الوسطى والكاريبي",
    "central american and caribbean games templates": "قوالب ألعاب أمريكا الوسطى والكاريبي",
    "central american games bids": "عروض ألعاب أمريكا الوسطى",
    "central american games competitions": "منافسات ألعاب أمريكا الوسطى",
    "central american games events": "أحداث ألعاب أمريكا الوسطى",
    "central american games festival": "مهرجانات ألعاب أمريكا الوسطى",
    "central american games templates": "قوالب ألعاب أمريكا الوسطى",
    "commonwealth games bids": "عروض ألعاب الكومنولث",
    "commonwealth games competitions": "منافسات ألعاب الكومنولث",
    "commonwealth games events": "أحداث ألعاب الكومنولث",
    "commonwealth games festival": "مهرجانات ألعاب الكومنولث",
    "commonwealth games templates": "قوالب ألعاب الكومنولث",
    "commonwealth youth games bids": "عروض ألعاب الكومنولث الشبابية",
    "commonwealth youth games competitions": "منافسات ألعاب الكومنولث الشبابية",
    "commonwealth youth games events": "أحداث ألعاب الكومنولث الشبابية",
    "commonwealth youth games festival": "مهرجانات ألعاب الكومنولث الشبابية",
    "commonwealth youth games templates": "قوالب ألعاب الكومنولث الشبابية",
    "deaflympic games bids": "عروض ألعاب ديفلمبياد",
    "deaflympic games competitions": "منافسات ألعاب ديفلمبياد",
    "deaflympic games events": "أحداث ألعاب ديفلمبياد",
    "deaflympic games festival": "مهرجانات ألعاب ديفلمبياد",
    "deaflympic games templates": "قوالب ألعاب ديفلمبياد",
    "east african games bids": "عروض الألعاب الإفريقية الشرقية",
    "east african games competitions": "منافسات الألعاب الإفريقية الشرقية",
    "east african games events": "أحداث الألعاب الإفريقية الشرقية",
    "east african games festival": "مهرجانات الألعاب الإفريقية الشرقية",
    "east african games templates": "قوالب الألعاب الإفريقية الشرقية",
    "east all-africa games bids": "عروض ألعاب عموم إفريقيا الشرقية",
    "east all-africa games competitions": "منافسات ألعاب عموم إفريقيا الشرقية",
    "east all-africa games events": "أحداث ألعاب عموم إفريقيا الشرقية",
    "east all-africa games festival": "مهرجانات ألعاب عموم إفريقيا الشرقية",
    "east all-africa games templates": "قوالب ألعاب عموم إفريقيا الشرقية",
    "east asian games bids": "عروض الألعاب الآسيوية الشرقية",
    "east asian games competitions": "منافسات الألعاب الآسيوية الشرقية",
    "east asian games events": "أحداث الألعاب الآسيوية الشرقية",
    "east asian games festival": "مهرجانات الألعاب الآسيوية الشرقية",
    "east asian games templates": "قوالب الألعاب الآسيوية الشرقية",
    "east central american games bids": "عروض ألعاب أمريكا الوسطى الشرقية",
    "east central american games competitions": "منافسات ألعاب أمريكا الوسطى الشرقية",
    "east central american games events": "أحداث ألعاب أمريكا الوسطى الشرقية",
    "east central american games festival": "مهرجانات ألعاب أمريكا الوسطى الشرقية",
    "east central american games templates": "قوالب ألعاب أمريكا الوسطى الشرقية",
    "east commonwealth games bids": "عروض ألعاب الكومنولث الشرقية",
    "east commonwealth games competitions": "منافسات ألعاب الكومنولث الشرقية",
    "east commonwealth games events": "أحداث ألعاب الكومنولث الشرقية",
    "east commonwealth games festival": "مهرجانات ألعاب الكومنولث الشرقية",
    "east commonwealth games templates": "قوالب ألعاب الكومنولث الشرقية",
    "east deaflympic games bids": "عروض ألعاب ديفلمبياد الشرقية",
    "east deaflympic games competitions": "منافسات ألعاب ديفلمبياد الشرقية",
    "east deaflympic games events": "أحداث ألعاب ديفلمبياد الشرقية",
    "east deaflympic games festival": "مهرجانات ألعاب ديفلمبياد الشرقية",
    "east deaflympic games templates": "قوالب ألعاب ديفلمبياد الشرقية",
    "east european youth olympic bids": "عروض الألعاب الأولمبية الشبابية الأوروبية الشرقية",
    "east european youth olympic competitions": "منافسات الألعاب الأولمبية الشبابية الأوروبية الشرقية",
    "east european youth olympic events": "أحداث الألعاب الأولمبية الشبابية الأوروبية الشرقية",
    "east european youth olympic festival": "مهرجانات الألعاب الأولمبية الشبابية الأوروبية الشرقية",
    "east european youth olympic templates": "قوالب الألعاب الأولمبية الشبابية الأوروبية الشرقية",
    "east european youth olympic winter bids": "عروض الألعاب الأولمبية الشبابية الأوروبية الشتوية الشرقية",
    "east european youth olympic winter competitions": "منافسات الألعاب الأولمبية الشبابية الأوروبية الشتوية الشرقية",
    "east european youth olympic winter events": "أحداث الألعاب الأولمبية الشبابية الأوروبية الشتوية الشرقية",
    "east european youth olympic winter festival": "مهرجانات الألعاب الأولمبية الشبابية الأوروبية الشتوية الشرقية",
    "east european youth olympic winter templates": "قوالب الألعاب الأولمبية الشبابية الأوروبية الشتوية الشرقية",
    "east jeux de la francophonie bids": "عروض الألعاب الفرانكوفونية الشرقية",
    "east jeux de la francophonie competitions": "منافسات الألعاب الفرانكوفونية الشرقية",
    "east jeux de la francophonie events": "أحداث الألعاب الفرانكوفونية الشرقية",
    "east jeux de la francophonie festival": "مهرجانات الألعاب الفرانكوفونية الشرقية",
    "east jeux de la francophonie templates": "قوالب الألعاب الفرانكوفونية الشرقية",
    "east olympic games bids": "عروض الألعاب الأولمبية الشرقية",
    "east olympic games competitions": "منافسات الألعاب الأولمبية الشرقية",
    "east olympic games events": "أحداث الألعاب الأولمبية الشرقية",
    "east olympic games festival": "مهرجانات الألعاب الأولمبية الشرقية",
    "east olympic games templates": "قوالب الألعاب الأولمبية الشرقية",
    "east olympics bids": "عروض الألعاب الأولمبية الشرقية",
    "east olympics competitions": "منافسات الألعاب الأولمبية الشرقية",
    "east olympics events": "أحداث الألعاب الأولمبية الشرقية",
    "east olympics festival": "مهرجانات الألعاب الأولمبية الشرقية",
    "east olympics templates": "قوالب الألعاب الأولمبية الشرقية",
    "east paralympics games bids": "عروض الألعاب البارالمبية الشرقية",
    "east paralympics games competitions": "منافسات الألعاب البارالمبية الشرقية",
    "east paralympics games events": "أحداث الألعاب البارالمبية الشرقية",
    "east paralympics games festival": "مهرجانات الألعاب البارالمبية الشرقية",
    "east paralympics games templates": "قوالب الألعاب البارالمبية الشرقية",
    "east south american games bids": "عروض ألعاب أمريكا الجنوبية الشرقية",
    "east south american games competitions": "منافسات ألعاب أمريكا الجنوبية الشرقية",
    "east south american games events": "أحداث ألعاب أمريكا الجنوبية الشرقية",
    "east south american games festival": "مهرجانات ألعاب أمريكا الجنوبية الشرقية",
    "east south american games templates": "قوالب ألعاب أمريكا الجنوبية الشرقية",
    "east universiade bids": "عروض الألعاب الجامعية الشرقية",
    "east universiade competitions": "منافسات الألعاب الجامعية الشرقية",
    "east universiade events": "أحداث الألعاب الجامعية الشرقية",
    "east universiade festival": "مهرجانات الألعاب الجامعية الشرقية",
    "east universiade templates": "قوالب الألعاب الجامعية الشرقية",
    "east world games bids": "عروض دورة الألعاب العالمية الشرقية",
    "east world games competitions": "منافسات دورة الألعاب العالمية الشرقية",
    "east world games events": "أحداث دورة الألعاب العالمية الشرقية",
    "east world games festival": "مهرجانات دورة الألعاب العالمية الشرقية",
    "east world games templates": "قوالب دورة الألعاب العالمية الشرقية",
    "east youth olympic games bids": "عروض الألعاب الأولمبية الشبابية الشرقية",
    "east youth olympic games competitions": "منافسات الألعاب الأولمبية الشبابية الشرقية",
    "east youth olympic games events": "أحداث الألعاب الأولمبية الشبابية الشرقية",
    "east youth olympic games festival": "مهرجانات الألعاب الأولمبية الشبابية الشرقية",
    "east youth olympic games templates": "قوالب الألعاب الأولمبية الشبابية الشرقية",
    "east youth olympics bids": "عروض الألعاب الأولمبية الشبابية الشرقية",
    "east youth olympics competitions": "منافسات الألعاب الأولمبية الشبابية الشرقية",
    "east youth olympics events": "أحداث الألعاب الأولمبية الشبابية الشرقية",
    "east youth olympics festival": "مهرجانات الألعاب الأولمبية الشبابية الشرقية",
    "east youth olympics templates": "قوالب الألعاب الأولمبية الشبابية الشرقية",
    "european games bids": "عروض الألعاب الأوروبية",
    "european games competitions": "منافسات الألعاب الأوروبية",
    "european games events": "أحداث الألعاب الأوروبية",
    "european games festival": "مهرجانات الألعاب الأوروبية",
    "european games templates": "قوالب الألعاب الأوروبية",
    "european youth olympic bids": "عروض الألعاب الأولمبية الشبابية الأوروبية",
    "european youth olympic competitions": "منافسات الألعاب الأولمبية الشبابية الأوروبية",
    "european youth olympic events": "أحداث الألعاب الأولمبية الشبابية الأوروبية",
    "european youth olympic festival": "مهرجانات الألعاب الأولمبية الشبابية الأوروبية",
    "european youth olympic templates": "قوالب الألعاب الأولمبية الشبابية الأوروبية",
    "european youth olympic winter bids": "عروض الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "european youth olympic winter competitions": "منافسات الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "european youth olympic winter events": "أحداث الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "european youth olympic winter festival": "مهرجانات الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "european youth olympic winter templates": "قوالب الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "fis nordic world ski championships bids": "عروض بطولة العالم للتزلج النوردي على الثلج",
    "fis nordic world ski championships competitions": "منافسات بطولة العالم للتزلج النوردي على الثلج",
    "fis nordic world ski championships events": "أحداث بطولة العالم للتزلج النوردي على الثلج",
    "fis nordic world ski championships festival": "مهرجانات بطولة العالم للتزلج النوردي على الثلج",
    "fis nordic world ski championships templates": "قوالب بطولة العالم للتزلج النوردي على الثلج",
    "friendship games bids": "عروض ألعاب الصداقة",
    "friendship games competitions": "منافسات ألعاب الصداقة",
    "friendship games events": "أحداث ألعاب الصداقة",
    "friendship games festival": "مهرجانات ألعاب الصداقة",
    "friendship games templates": "قوالب ألعاب الصداقة",
    "goodwill games bids": "عروض ألعاب النوايا الحسنة",
    "goodwill games competitions": "منافسات ألعاب النوايا الحسنة",
    "goodwill games events": "أحداث ألعاب النوايا الحسنة",
    "goodwill games festival": "مهرجانات ألعاب النوايا الحسنة",
    "goodwill games templates": "قوالب ألعاب النوايا الحسنة",
    "islamic solidarity games bids": "عروض ألعاب التضامن الإسلامي",
    "islamic solidarity games competitions": "منافسات ألعاب التضامن الإسلامي",
    "islamic solidarity games events": "أحداث ألعاب التضامن الإسلامي",
    "islamic solidarity games festival": "مهرجانات ألعاب التضامن الإسلامي",
    "islamic solidarity games templates": "قوالب ألعاب التضامن الإسلامي",
    "jeux de la francophonie bids": "عروض الألعاب الفرانكوفونية",
    "jeux de la francophonie competitions": "منافسات الألعاب الفرانكوفونية",
    "jeux de la francophonie events": "أحداث الألعاب الفرانكوفونية",
    "jeux de la francophonie festival": "مهرجانات الألعاب الفرانكوفونية",
    "jeux de la francophonie templates": "قوالب الألعاب الفرانكوفونية",
    "maccabiah games bids": "عروض الألعاب المكابيه",
    "maccabiah games competitions": "منافسات الألعاب المكابيه",
    "maccabiah games events": "أحداث الألعاب المكابيه",
    "maccabiah games festival": "مهرجانات الألعاب المكابيه",
    "maccabiah games templates": "قوالب الألعاب المكابيه",
    "mediterranean games bids": "عروض الألعاب المتوسطية",
    "mediterranean games competitions": "منافسات الألعاب المتوسطية",
    "mediterranean games events": "أحداث الألعاب المتوسطية",
    "mediterranean games festival": "مهرجانات الألعاب المتوسطية",
    "mediterranean games templates": "قوالب الألعاب المتوسطية",
    "micronesian games bids": "عروض الألعاب الميكرونيزية",
    "micronesian games competitions": "منافسات الألعاب الميكرونيزية",
    "micronesian games events": "أحداث الألعاب الميكرونيزية",
    "micronesian games festival": "مهرجانات الألعاب الميكرونيزية",
    "micronesian games templates": "قوالب الألعاب الميكرونيزية",
    "military world games bids": "عروض دورة الألعاب العسكرية",
    "military world games competitions": "منافسات دورة الألعاب العسكرية",
    "military world games events": "أحداث دورة الألعاب العسكرية",
    "military world games festival": "مهرجانات دورة الألعاب العسكرية",
    "military world games templates": "قوالب دورة الألعاب العسكرية",
    "olympic games bids": "عروض الألعاب الأولمبية",
    "olympic games competitions": "منافسات الألعاب الأولمبية",
    "olympic games events": "أحداث الألعاب الأولمبية",
    "olympic games festival": "مهرجانات الألعاب الأولمبية",
    "olympic games templates": "قوالب الألعاب الأولمبية",
    "olympics bids": "عروض الألعاب الأولمبية",
    "olympics competitions": "منافسات الألعاب الأولمبية",
    "olympics events": "أحداث الألعاب الأولمبية",
    "olympics festival": "مهرجانات الألعاب الأولمبية",
    "olympics templates": "قوالب الألعاب الأولمبية",
    "pan american games bids": "عروض دورة الألعاب الأمريكية",
    "pan american games competitions": "منافسات دورة الألعاب الأمريكية",
    "pan american games events": "أحداث دورة الألعاب الأمريكية",
    "pan american games festival": "مهرجانات دورة الألعاب الأمريكية",
    "pan american games templates": "قوالب دورة الألعاب الأمريكية",
    "pan arab games bids": "عروض دورة الألعاب العربية",
    "pan arab games competitions": "منافسات دورة الألعاب العربية",
    "pan arab games events": "أحداث دورة الألعاب العربية",
    "pan arab games festival": "مهرجانات دورة الألعاب العربية",
    "pan arab games templates": "قوالب دورة الألعاب العربية",
    "pan asian games bids": "عروض دورة الألعاب الآسيوية",
    "pan asian games competitions": "منافسات دورة الألعاب الآسيوية",
    "pan asian games events": "أحداث دورة الألعاب الآسيوية",
    "pan asian games festival": "مهرجانات دورة الألعاب الآسيوية",
    "pan asian games templates": "قوالب دورة الألعاب الآسيوية",
    "paralympic bids": "عروض الألعاب البارالمبية",
    "paralympic competitions": "منافسات الألعاب البارالمبية",
    "paralympic events": "أحداث الألعاب البارالمبية",
    "paralympic festival": "مهرجانات الألعاب البارالمبية",
    "paralympic templates": "قوالب الألعاب البارالمبية",
    "paralympics bids": "عروض الألعاب البارالمبية",
    "paralympics competitions": "منافسات الألعاب البارالمبية",
    "paralympics events": "أحداث الألعاب البارالمبية",
    "paralympics festival": "مهرجانات الألعاب البارالمبية",
    "paralympics games bids": "عروض الألعاب البارالمبية",
    "paralympics games competitions": "منافسات الألعاب البارالمبية",
    "paralympics games events": "أحداث الألعاب البارالمبية",
    "paralympics games festival": "مهرجانات الألعاب البارالمبية",
    "paralympics games templates": "قوالب الألعاب البارالمبية",
    "paralympics templates": "قوالب الألعاب البارالمبية",
    "parapan american games bids": "عروض ألعاب بارابان الأمريكية",
    "parapan american games competitions": "منافسات ألعاب بارابان الأمريكية",
    "parapan american games events": "أحداث ألعاب بارابان الأمريكية",
    "parapan american games festival": "مهرجانات ألعاب بارابان الأمريكية",
    "parapan american games templates": "قوالب ألعاب بارابان الأمريكية",
    "sea games bids": "عروض ألعاب البحر",
    "sea games competitions": "منافسات ألعاب البحر",
    "sea games events": "أحداث ألعاب البحر",
    "sea games festival": "مهرجانات ألعاب البحر",
    "sea games templates": "قوالب ألعاب البحر",
    "south american games bids": "عروض ألعاب أمريكا الجنوبية",
    "south american games competitions": "منافسات ألعاب أمريكا الجنوبية",
    "south american games events": "أحداث ألعاب أمريكا الجنوبية",
    "south american games festival": "مهرجانات ألعاب أمريكا الجنوبية",
    "south american games templates": "قوالب ألعاب أمريكا الجنوبية",
    "south asian beach games bids": "عروض دورة ألعاب جنوب أسيا الشاطئية",
    "south asian beach games competitions": "منافسات دورة ألعاب جنوب أسيا الشاطئية",
    "south asian beach games events": "أحداث دورة ألعاب جنوب أسيا الشاطئية",
    "south asian beach games festival": "مهرجانات دورة ألعاب جنوب أسيا الشاطئية",
    "south asian beach games templates": "قوالب دورة ألعاب جنوب أسيا الشاطئية",
    "south asian games bids": "عروض ألعاب جنوب أسيا",
    "south asian games competitions": "منافسات ألعاب جنوب أسيا",
    "south asian games events": "أحداث ألعاب جنوب أسيا",
    "south asian games festival": "مهرجانات ألعاب جنوب أسيا",
    "south asian games templates": "قوالب ألعاب جنوب أسيا",
    "south asian winter games bids": "عروض ألعاب جنوب آسيا الشتوية",
    "south asian winter games competitions": "منافسات ألعاب جنوب آسيا الشتوية",
    "south asian winter games events": "أحداث ألعاب جنوب آسيا الشتوية",
    "south asian winter games festival": "مهرجانات ألعاب جنوب آسيا الشتوية",
    "south asian winter games templates": "قوالب ألعاب جنوب آسيا الشتوية",
    "southeast asian games bids": "عروض ألعاب جنوب شرق آسيا",
    "southeast asian games competitions": "منافسات ألعاب جنوب شرق آسيا",
    "southeast asian games events": "أحداث ألعاب جنوب شرق آسيا",
    "southeast asian games festival": "مهرجانات ألعاب جنوب شرق آسيا",
    "southeast asian games templates": "قوالب ألعاب جنوب شرق آسيا",
    "summer african games bids": "عروض الألعاب الإفريقية الصيفية",
    "summer african games competitions": "منافسات الألعاب الإفريقية الصيفية",
    "summer african games events": "أحداث الألعاب الإفريقية الصيفية",
    "summer african games festival": "مهرجانات الألعاب الإفريقية الصيفية",
    "summer african games templates": "قوالب الألعاب الإفريقية الصيفية",
    "summer all-africa games bids": "عروض ألعاب عموم إفريقيا الصيفية",
    "summer all-africa games competitions": "منافسات ألعاب عموم إفريقيا الصيفية",
    "summer all-africa games events": "أحداث ألعاب عموم إفريقيا الصيفية",
    "summer all-africa games festival": "مهرجانات ألعاب عموم إفريقيا الصيفية",
    "summer all-africa games templates": "قوالب ألعاب عموم إفريقيا الصيفية",
    "summer asian games bids": "عروض الألعاب الآسيوية الصيفية",
    "summer asian games competitions": "منافسات الألعاب الآسيوية الصيفية",
    "summer asian games events": "أحداث الألعاب الآسيوية الصيفية",
    "summer asian games festival": "مهرجانات الألعاب الآسيوية الصيفية",
    "summer asian games templates": "قوالب الألعاب الآسيوية الصيفية",
    "summer central american games bids": "عروض ألعاب أمريكا الوسطى الصيفية",
    "summer central american games competitions": "منافسات ألعاب أمريكا الوسطى الصيفية",
    "summer central american games events": "أحداث ألعاب أمريكا الوسطى الصيفية",
    "summer central american games festival": "مهرجانات ألعاب أمريكا الوسطى الصيفية",
    "summer central american games templates": "قوالب ألعاب أمريكا الوسطى الصيفية",
    "summer commonwealth games bids": "عروض ألعاب الكومنولث الصيفية",
    "summer commonwealth games competitions": "منافسات ألعاب الكومنولث الصيفية",
    "summer commonwealth games events": "أحداث ألعاب الكومنولث الصيفية",
    "summer commonwealth games festival": "مهرجانات ألعاب الكومنولث الصيفية",
    "summer commonwealth games templates": "قوالب ألعاب الكومنولث الصيفية",
    "summer deaflympic games bids": "عروض ألعاب ديفلمبياد الصيفية",
    "summer deaflympic games competitions": "منافسات ألعاب ديفلمبياد الصيفية",
    "summer deaflympic games events": "أحداث ألعاب ديفلمبياد الصيفية",
    "summer deaflympic games festival": "مهرجانات ألعاب ديفلمبياد الصيفية",
    "summer deaflympic games templates": "قوالب ألعاب ديفلمبياد الصيفية",
    "summer european youth olympic bids": "عروض الألعاب الأولمبية الشبابية الأوروبية الصيفية",
    "summer european youth olympic competitions": "منافسات الألعاب الأولمبية الشبابية الأوروبية الصيفية",
    "summer european youth olympic events": "أحداث الألعاب الأولمبية الشبابية الأوروبية الصيفية",
    "summer european youth olympic festival": "مهرجانات الألعاب الأولمبية الشبابية الأوروبية الصيفية",
    "summer european youth olympic templates": "قوالب الألعاب الأولمبية الشبابية الأوروبية الصيفية",
    "summer european youth olympic winter bids": "عروض الألعاب الأولمبية الشبابية الأوروبية الشتوية الصيفية",
    "summer european youth olympic winter competitions": "منافسات الألعاب الأولمبية الشبابية الأوروبية الشتوية الصيفية",
    "summer european youth olympic winter events": "أحداث الألعاب الأولمبية الشبابية الأوروبية الشتوية الصيفية",
    "summer european youth olympic winter festival": "مهرجانات الألعاب الأولمبية الشبابية الأوروبية الشتوية الصيفية",
    "summer european youth olympic winter templates": "قوالب الألعاب الأولمبية الشبابية الأوروبية الشتوية الصيفية",
    "summer jeux de la francophonie bids": "عروض الألعاب الفرانكوفونية الصيفية",
    "summer jeux de la francophonie competitions": "منافسات الألعاب الفرانكوفونية الصيفية",
    "summer jeux de la francophonie events": "أحداث الألعاب الفرانكوفونية الصيفية",
    "summer jeux de la francophonie festival": "مهرجانات الألعاب الفرانكوفونية الصيفية",
    "summer jeux de la francophonie templates": "قوالب الألعاب الفرانكوفونية الصيفية",
    "summer olympic games bids": "عروض الألعاب الأولمبية الصيفية",
    "summer olympic games competitions": "منافسات الألعاب الأولمبية الصيفية",
    "summer olympic games events": "أحداث الألعاب الأولمبية الصيفية",
    "summer olympic games festival": "مهرجانات الألعاب الأولمبية الصيفية",
    "summer olympic games templates": "قوالب الألعاب الأولمبية الصيفية",
    "summer olympics bids": "عروض الألعاب الأولمبية الصيفية",
    "summer olympics competitions": "منافسات الألعاب الأولمبية الصيفية",
    "summer olympics events": "أحداث الألعاب الأولمبية الصيفية",
    "summer olympics festival": "مهرجانات الألعاب الأولمبية الصيفية",
    "summer olympics templates": "قوالب الألعاب الأولمبية الصيفية",
    "summer paralympics games bids": "عروض الألعاب البارالمبية الصيفية",
    "summer paralympics games competitions": "منافسات الألعاب البارالمبية الصيفية",
    "summer paralympics games events": "أحداث الألعاب البارالمبية الصيفية",
    "summer paralympics games festival": "مهرجانات الألعاب البارالمبية الصيفية",
    "summer paralympics games templates": "قوالب الألعاب البارالمبية الصيفية",
    "summer south american games bids": "عروض ألعاب أمريكا الجنوبية الصيفية",
    "summer south american games competitions": "منافسات ألعاب أمريكا الجنوبية الصيفية",
    "summer south american games events": "أحداث ألعاب أمريكا الجنوبية الصيفية",
    "summer south american games festival": "مهرجانات ألعاب أمريكا الجنوبية الصيفية",
    "summer south american games templates": "قوالب ألعاب أمريكا الجنوبية الصيفية",
    "summer universiade bids": "عروض الألعاب الجامعية الصيفية",
    "summer universiade competitions": "منافسات الألعاب الجامعية الصيفية",
    "summer universiade events": "أحداث الألعاب الجامعية الصيفية",
    "summer universiade festival": "مهرجانات الألعاب الجامعية الصيفية",
    "summer universiade templates": "قوالب الألعاب الجامعية الصيفية",
    "summer world games bids": "عروض دورة الألعاب العالمية الصيفية",
    "summer world games competitions": "منافسات دورة الألعاب العالمية الصيفية",
    "summer world games events": "أحداث دورة الألعاب العالمية الصيفية",
    "summer world games festival": "مهرجانات دورة الألعاب العالمية الصيفية",
    "summer world games templates": "قوالب دورة الألعاب العالمية الصيفية",
    "summer world university games bids": "عروض ألعاب الجامعات العالمية الصيفية",
    "summer world university games competitions": "منافسات ألعاب الجامعات العالمية الصيفية",
    "summer world university games events": "أحداث ألعاب الجامعات العالمية الصيفية",
    "summer world university games festival": "مهرجانات ألعاب الجامعات العالمية الصيفية",
    "summer world university games templates": "قوالب ألعاب الجامعات العالمية الصيفية",
    "summer youth olympic games bids": "عروض الألعاب الأولمبية الشبابية الصيفية",
    "summer youth olympic games competitions": "منافسات الألعاب الأولمبية الشبابية الصيفية",
    "summer youth olympic games events": "أحداث الألعاب الأولمبية الشبابية الصيفية",
    "summer youth olympic games festival": "مهرجانات الألعاب الأولمبية الشبابية الصيفية",
    "summer youth olympic games templates": "قوالب الألعاب الأولمبية الشبابية الصيفية",
    "summer youth olympics bids": "عروض الألعاب الأولمبية الشبابية الصيفية",
    "summer youth olympics competitions": "منافسات الألعاب الأولمبية الشبابية الصيفية",
    "summer youth olympics events": "أحداث الألعاب الأولمبية الشبابية الصيفية",
    "summer youth olympics festival": "مهرجانات الألعاب الأولمبية الشبابية الصيفية",
    "summer youth olympics templates": "قوالب الألعاب الأولمبية الشبابية الصيفية",
    "the universiade bids": "عروض الألعاب الجامعية",
    "the universiade competitions": "منافسات الألعاب الجامعية",
    "the universiade events": "أحداث الألعاب الجامعية",
    "the universiade festival": "مهرجانات الألعاب الجامعية",
    "the universiade templates": "قوالب الألعاب الجامعية",
    "universiade bids": "عروض الألعاب الجامعية",
    "universiade competitions": "منافسات الألعاب الجامعية",
    "universiade events": "أحداث الألعاب الجامعية",
    "universiade festival": "مهرجانات الألعاب الجامعية",
    "universiade templates": "قوالب الألعاب الجامعية",
    "west african games bids": "عروض الألعاب الإفريقية الغربية",
    "west african games competitions": "منافسات الألعاب الإفريقية الغربية",
    "west african games events": "أحداث الألعاب الإفريقية الغربية",
    "west african games festival": "مهرجانات الألعاب الإفريقية الغربية",
    "west african games templates": "قوالب الألعاب الإفريقية الغربية",
    "west all-africa games bids": "عروض ألعاب عموم إفريقيا الغربية",
    "west all-africa games competitions": "منافسات ألعاب عموم إفريقيا الغربية",
    "west all-africa games events": "أحداث ألعاب عموم إفريقيا الغربية",
    "west all-africa games festival": "مهرجانات ألعاب عموم إفريقيا الغربية",
    "west all-africa games templates": "قوالب ألعاب عموم إفريقيا الغربية",
    "west asian games bids": "عروض الألعاب الآسيوية الغربية",
    "west asian games competitions": "منافسات الألعاب الآسيوية الغربية",
    "west asian games events": "أحداث الألعاب الآسيوية الغربية",
    "west asian games festival": "مهرجانات الألعاب الآسيوية الغربية",
    "west asian games templates": "قوالب الألعاب الآسيوية الغربية",
    "west central american games bids": "عروض ألعاب أمريكا الوسطى الغربية",
    "west central american games competitions": "منافسات ألعاب أمريكا الوسطى الغربية",
    "west central american games events": "أحداث ألعاب أمريكا الوسطى الغربية",
    "west central american games festival": "مهرجانات ألعاب أمريكا الوسطى الغربية",
    "west central american games templates": "قوالب ألعاب أمريكا الوسطى الغربية",
    "west commonwealth games bids": "عروض ألعاب الكومنولث الغربية",
    "west commonwealth games competitions": "منافسات ألعاب الكومنولث الغربية",
    "west commonwealth games events": "أحداث ألعاب الكومنولث الغربية",
    "west commonwealth games festival": "مهرجانات ألعاب الكومنولث الغربية",
    "west commonwealth games templates": "قوالب ألعاب الكومنولث الغربية",
    "west deaflympic games bids": "عروض ألعاب ديفلمبياد الغربية",
    "west deaflympic games competitions": "منافسات ألعاب ديفلمبياد الغربية",
    "west deaflympic games events": "أحداث ألعاب ديفلمبياد الغربية",
    "west deaflympic games festival": "مهرجانات ألعاب ديفلمبياد الغربية",
    "west deaflympic games templates": "قوالب ألعاب ديفلمبياد الغربية",
    "west european youth olympic bids": "عروض الألعاب الأولمبية الشبابية الأوروبية الغربية",
    "west european youth olympic competitions": "منافسات الألعاب الأولمبية الشبابية الأوروبية الغربية",
    "west european youth olympic events": "أحداث الألعاب الأولمبية الشبابية الأوروبية الغربية",
    "west european youth olympic festival": "مهرجانات الألعاب الأولمبية الشبابية الأوروبية الغربية",
    "west european youth olympic templates": "قوالب الألعاب الأولمبية الشبابية الأوروبية الغربية",
    "west european youth olympic winter bids": "عروض الألعاب الأولمبية الشبابية الأوروبية الشتوية الغربية",
    "west european youth olympic winter competitions": "منافسات الألعاب الأولمبية الشبابية الأوروبية الشتوية الغربية",
    "west european youth olympic winter events": "أحداث الألعاب الأولمبية الشبابية الأوروبية الشتوية الغربية",
    "west european youth olympic winter festival": "مهرجانات الألعاب الأولمبية الشبابية الأوروبية الشتوية الغربية",
    "west european youth olympic winter templates": "قوالب الألعاب الأولمبية الشبابية الأوروبية الشتوية الغربية",
    "west jeux de la francophonie bids": "عروض الألعاب الفرانكوفونية الغربية",
    "west jeux de la francophonie competitions": "منافسات الألعاب الفرانكوفونية الغربية",
    "west jeux de la francophonie events": "أحداث الألعاب الفرانكوفونية الغربية",
    "west jeux de la francophonie festival": "مهرجانات الألعاب الفرانكوفونية الغربية",
    "west jeux de la francophonie templates": "قوالب الألعاب الفرانكوفونية الغربية",
    "west olympic games bids": "عروض الألعاب الأولمبية الغربية",
    "west olympic games competitions": "منافسات الألعاب الأولمبية الغربية",
    "west olympic games events": "أحداث الألعاب الأولمبية الغربية",
    "west olympic games festival": "مهرجانات الألعاب الأولمبية الغربية",
    "west olympic games templates": "قوالب الألعاب الأولمبية الغربية",
    "west olympics bids": "عروض الألعاب الأولمبية الغربية",
    "west olympics competitions": "منافسات الألعاب الأولمبية الغربية",
    "west olympics events": "أحداث الألعاب الأولمبية الغربية",
    "west olympics festival": "مهرجانات الألعاب الأولمبية الغربية",
    "west olympics templates": "قوالب الألعاب الأولمبية الغربية",
    "west paralympics games bids": "عروض الألعاب البارالمبية الغربية",
    "west paralympics games competitions": "منافسات الألعاب البارالمبية الغربية",
    "west paralympics games events": "أحداث الألعاب البارالمبية الغربية",
    "west paralympics games festival": "مهرجانات الألعاب البارالمبية الغربية",
    "west paralympics games templates": "قوالب الألعاب البارالمبية الغربية",
    "west south american games bids": "عروض ألعاب أمريكا الجنوبية الغربية",
    "west south american games competitions": "منافسات ألعاب أمريكا الجنوبية الغربية",
    "west south american games events": "أحداث ألعاب أمريكا الجنوبية الغربية",
    "west south american games festival": "مهرجانات ألعاب أمريكا الجنوبية الغربية",
    "west south american games templates": "قوالب ألعاب أمريكا الجنوبية الغربية",
    "west universiade bids": "عروض الألعاب الجامعية الغربية",
    "west universiade competitions": "منافسات الألعاب الجامعية الغربية",
    "west universiade events": "أحداث الألعاب الجامعية الغربية",
    "west universiade festival": "مهرجانات الألعاب الجامعية الغربية",
    "west universiade templates": "قوالب الألعاب الجامعية الغربية",
    "west world games bids": "عروض دورة الألعاب العالمية الغربية",
    "west world games competitions": "منافسات دورة الألعاب العالمية الغربية",
    "west world games events": "أحداث دورة الألعاب العالمية الغربية",
    "west world games festival": "مهرجانات دورة الألعاب العالمية الغربية",
    "west world games templates": "قوالب دورة الألعاب العالمية الغربية",
    "west youth olympic games bids": "عروض الألعاب الأولمبية الشبابية الغربية",
    "west youth olympic games competitions": "منافسات الألعاب الأولمبية الشبابية الغربية",
    "west youth olympic games events": "أحداث الألعاب الأولمبية الشبابية الغربية",
    "west youth olympic games festival": "مهرجانات الألعاب الأولمبية الشبابية الغربية",
    "west youth olympic games templates": "قوالب الألعاب الأولمبية الشبابية الغربية",
    "west youth olympics bids": "عروض الألعاب الأولمبية الشبابية الغربية",
    "west youth olympics competitions": "منافسات الألعاب الأولمبية الشبابية الغربية",
    "west youth olympics events": "أحداث الألعاب الأولمبية الشبابية الغربية",
    "west youth olympics festival": "مهرجانات الألعاب الأولمبية الشبابية الغربية",
    "west youth olympics templates": "قوالب الألعاب الأولمبية الشبابية الغربية",
    "winter african games bids": "عروض الألعاب الإفريقية الشتوية",
    "winter african games competitions": "منافسات الألعاب الإفريقية الشتوية",
    "winter african games events": "أحداث الألعاب الإفريقية الشتوية",
    "winter african games festival": "مهرجانات الألعاب الإفريقية الشتوية",
    "winter african games templates": "قوالب الألعاب الإفريقية الشتوية",
    "winter all-africa games bids": "عروض ألعاب عموم إفريقيا الشتوية",
    "winter all-africa games competitions": "منافسات ألعاب عموم إفريقيا الشتوية",
    "winter all-africa games events": "أحداث ألعاب عموم إفريقيا الشتوية",
    "winter all-africa games festival": "مهرجانات ألعاب عموم إفريقيا الشتوية",
    "winter all-africa games templates": "قوالب ألعاب عموم إفريقيا الشتوية",
    "winter asian games bids": "عروض الألعاب الآسيوية الشتوية",
    "winter asian games competitions": "منافسات الألعاب الآسيوية الشتوية",
    "winter asian games events": "أحداث الألعاب الآسيوية الشتوية",
    "winter asian games festival": "مهرجانات الألعاب الآسيوية الشتوية",
    "winter asian games templates": "قوالب الألعاب الآسيوية الشتوية",
    "winter central american games bids": "عروض ألعاب أمريكا الوسطى الشتوية",
    "winter central american games competitions": "منافسات ألعاب أمريكا الوسطى الشتوية",
    "winter central american games events": "أحداث ألعاب أمريكا الوسطى الشتوية",
    "winter central american games festival": "مهرجانات ألعاب أمريكا الوسطى الشتوية",
    "winter central american games templates": "قوالب ألعاب أمريكا الوسطى الشتوية",
    "winter commonwealth games bids": "عروض ألعاب الكومنولث الشتوية",
    "winter commonwealth games competitions": "منافسات ألعاب الكومنولث الشتوية",
    "winter commonwealth games events": "أحداث ألعاب الكومنولث الشتوية",
    "winter commonwealth games festival": "مهرجانات ألعاب الكومنولث الشتوية",
    "winter commonwealth games templates": "قوالب ألعاب الكومنولث الشتوية",
    "winter deaflympic games bids": "عروض ألعاب ديفلمبياد الشتوية",
    "winter deaflympic games competitions": "منافسات ألعاب ديفلمبياد الشتوية",
    "winter deaflympic games events": "أحداث ألعاب ديفلمبياد الشتوية",
    "winter deaflympic games festival": "مهرجانات ألعاب ديفلمبياد الشتوية",
    "winter deaflympic games templates": "قوالب ألعاب ديفلمبياد الشتوية",
    "winter european youth olympic bids": "عروض الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "winter european youth olympic competitions": "منافسات الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "winter european youth olympic events": "أحداث الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "winter european youth olympic festival": "مهرجانات الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "winter european youth olympic templates": "قوالب الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "winter european youth olympic winter bids": "عروض الألعاب الأولمبية الشبابية الأوروبية الشتوية الشتوية",
    "winter european youth olympic winter competitions": "منافسات الألعاب الأولمبية الشبابية الأوروبية الشتوية الشتوية",
    "winter european youth olympic winter events": "أحداث الألعاب الأولمبية الشبابية الأوروبية الشتوية الشتوية",
    "winter european youth olympic winter festival": "مهرجانات الألعاب الأولمبية الشبابية الأوروبية الشتوية الشتوية",
    "winter european youth olympic winter templates": "قوالب الألعاب الأولمبية الشبابية الأوروبية الشتوية الشتوية",
    "winter jeux de la francophonie bids": "عروض الألعاب الفرانكوفونية الشتوية",
    "winter jeux de la francophonie competitions": "منافسات الألعاب الفرانكوفونية الشتوية",
    "winter jeux de la francophonie events": "أحداث الألعاب الفرانكوفونية الشتوية",
    "winter jeux de la francophonie festival": "مهرجانات الألعاب الفرانكوفونية الشتوية",
    "winter jeux de la francophonie templates": "قوالب الألعاب الفرانكوفونية الشتوية",
    "winter olympic games bids": "عروض الألعاب الأولمبية الشتوية",
    "winter olympic games competitions": "منافسات الألعاب الأولمبية الشتوية",
    "winter olympic games events": "أحداث الألعاب الأولمبية الشتوية",
    "winter olympic games festival": "مهرجانات الألعاب الأولمبية الشتوية",
    "winter olympic games templates": "قوالب الألعاب الأولمبية الشتوية",
    "winter olympics bids": "عروض الألعاب الأولمبية الشتوية",
    "winter olympics competitions": "منافسات الألعاب الأولمبية الشتوية",
    "winter olympics events": "أحداث الألعاب الأولمبية الشتوية",
    "winter olympics festival": "مهرجانات الألعاب الأولمبية الشتوية",
    "winter olympics templates": "قوالب الألعاب الأولمبية الشتوية",
    "winter paralympics games bids": "عروض الألعاب البارالمبية الشتوية",
    "winter paralympics games competitions": "منافسات الألعاب البارالمبية الشتوية",
    "winter paralympics games events": "أحداث الألعاب البارالمبية الشتوية",
    "winter paralympics games festival": "مهرجانات الألعاب البارالمبية الشتوية",
    "winter paralympics games templates": "قوالب الألعاب البارالمبية الشتوية",
    "winter south american games bids": "عروض ألعاب أمريكا الجنوبية الشتوية",
    "winter south american games competitions": "منافسات ألعاب أمريكا الجنوبية الشتوية",
    "winter south american games events": "أحداث ألعاب أمريكا الجنوبية الشتوية",
    "winter south american games festival": "مهرجانات ألعاب أمريكا الجنوبية الشتوية",
    "winter south american games templates": "قوالب ألعاب أمريكا الجنوبية الشتوية",
    "winter universiade bids": "عروض الألعاب الجامعية الشتوية",
    "winter universiade competitions": "منافسات الألعاب الجامعية الشتوية",
    "winter universiade events": "أحداث الألعاب الجامعية الشتوية",
    "winter universiade festival": "مهرجانات الألعاب الجامعية الشتوية",
    "winter universiade templates": "قوالب الألعاب الجامعية الشتوية",
    "winter world games bids": "عروض دورة الألعاب العالمية الشتوية",
    "winter world games competitions": "منافسات دورة الألعاب العالمية الشتوية",
    "winter world games events": "أحداث دورة الألعاب العالمية الشتوية",
    "winter world games festival": "مهرجانات دورة الألعاب العالمية الشتوية",
    "winter world games templates": "قوالب دورة الألعاب العالمية الشتوية",
    "winter world university games bids": "عروض ألعاب الجامعات العالمية الشتوية",
    "winter world university games competitions": "منافسات ألعاب الجامعات العالمية الشتوية",
    "winter world university games events": "أحداث ألعاب الجامعات العالمية الشتوية",
    "winter world university games festival": "مهرجانات ألعاب الجامعات العالمية الشتوية",
    "winter world university games templates": "قوالب ألعاب الجامعات العالمية الشتوية",
    "winter youth olympic games bids": "عروض الألعاب الأولمبية الشبابية الشتوية",
    "winter youth olympic games competitions": "منافسات الألعاب الأولمبية الشبابية الشتوية",
    "winter youth olympic games events": "أحداث الألعاب الأولمبية الشبابية الشتوية",
    "winter youth olympic games festival": "مهرجانات الألعاب الأولمبية الشبابية الشتوية",
    "winter youth olympic games templates": "قوالب الألعاب الأولمبية الشبابية الشتوية",
    "winter youth olympics bids": "عروض الألعاب الأولمبية الشبابية الشتوية",
    "winter youth olympics competitions": "منافسات الألعاب الأولمبية الشبابية الشتوية",
    "winter youth olympics events": "أحداث الألعاب الأولمبية الشبابية الشتوية",
    "winter youth olympics festival": "مهرجانات الألعاب الأولمبية الشبابية الشتوية",
    "winter youth olympics templates": "قوالب الألعاب الأولمبية الشبابية الشتوية",
    "world championships bids": "عروض بطولات العالم",
    "world championships competitions": "منافسات بطولات العالم",
    "world championships events": "أحداث بطولات العالم",
    "world championships festival": "مهرجانات بطولات العالم",
    "world championships templates": "قوالب بطولات العالم",
    "world games bids": "عروض دورة الألعاب العالمية",
    "world games competitions": "منافسات دورة الألعاب العالمية",
    "world games events": "أحداث دورة الألعاب العالمية",
    "world games festival": "مهرجانات دورة الألعاب العالمية",
    "world games templates": "قوالب دورة الألعاب العالمية",
    "youth olympic bids": "عروض الألعاب الأولمبية الشبابية",
    "youth olympic competitions": "منافسات الألعاب الأولمبية الشبابية",
    "youth olympic events": "أحداث الألعاب الأولمبية الشبابية",
    "youth olympic festival": "مهرجانات الألعاب الأولمبية الشبابية",
    "youth olympic games bids": "عروض الألعاب الأولمبية الشبابية",
    "youth olympic games competitions": "منافسات الألعاب الأولمبية الشبابية",
    "youth olympic games events": "أحداث الألعاب الأولمبية الشبابية",
    "youth olympic games festival": "مهرجانات الألعاب الأولمبية الشبابية",
    "youth olympic games templates": "قوالب الألعاب الأولمبية الشبابية",
    "youth olympic templates": "قوالب الألعاب الأولمبية الشبابية",
    "youth olympics bids": "عروض الألعاب الأولمبية الشبابية",
    "youth olympics competitions": "منافسات الألعاب الأولمبية الشبابية",
    "youth olympics events": "أحداث الألعاب الأولمبية الشبابية",
    "youth olympics festival": "مهرجانات الألعاب الأولمبية الشبابية",
    "youth olympics games bids": "عروض الألعاب الأولمبية الشبابية",
    "youth olympics games competitions": "منافسات الألعاب الأولمبية الشبابية",
    "youth olympics games events": "أحداث الألعاب الأولمبية الشبابية",
    "youth olympics games festival": "مهرجانات الألعاب الأولمبية الشبابية",
    "youth olympics games templates": "قوالب الألعاب الأولمبية الشبابية",
    "youth olympics templates": "قوالب الألعاب الأولمبية الشبابية",
}

summer_winter_games = {
    "african games": "الألعاب الإفريقية",
    "asian beach games": "دورة الألعاب الآسيوية الشاطئية",
    "asian games": "الألعاب الآسيوية",
    "asian indoor games": "دورة الألعاب الآسيوية داخل الصالات",
    "asian para games": "الألعاب البارالمبية الآسيوية",
    "asian summer games": "الألعاب الآسيوية الصيفية",
    "asian winter games": "الألعاب الآسيوية الشتوية",
    "bolivarian games": "الألعاب البوليفارية",
    "central american and caribbean games": "ألعاب أمريكا الوسطى والكاريبي",
    "central american games": "ألعاب أمريكا الوسطى",
    "commonwealth games": "ألعاب الكومنولث",
    "commonwealth youth games": "ألعاب الكومنولث الشبابية",
    "deaflympic games": "ألعاب ديفلمبياد",
    "european games": "الألعاب الأوروبية",
    "european youth olympic": "الألعاب الأولمبية الشبابية الأوروبية",
    "european youth olympic winter": "الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "fis nordic world ski championships": "بطولة العالم للتزلج النوردي على الثلج",
    "friendship games": "ألعاب الصداقة",
    "goodwill games": "ألعاب النوايا الحسنة",
    "islamic solidarity games": "ألعاب التضامن الإسلامي",
    "maccabiah games": "الألعاب المكابيه",
    "mediterranean games": "الألعاب المتوسطية",
    "micronesian games": "الألعاب الميكرونيزية",
    "military world games": "دورة الألعاب العسكرية",
    "pan american games": "دورة الألعاب الأمريكية",
    "pan arab games": "دورة الألعاب العربية",
    "pan asian games": "دورة الألعاب الآسيوية",
    "paralympic": "الألعاب البارالمبية",
    "paralympics": "الألعاب البارالمبية",
    "parapan american games": "ألعاب بارابان الأمريكية",
    "sea games": "ألعاب البحر",
    "south american games": "ألعاب أمريكا الجنوبية",
    "south asian beach games": "دورة ألعاب جنوب أسيا الشاطئية",
    "south asian games": "ألعاب جنوب أسيا",
    "south asian winter games": "ألعاب جنوب آسيا الشتوية",
    "southeast asian games": "ألعاب جنوب شرق آسيا",
    "summer olympics": "الألعاب الأولمبية الصيفية",
    "summer universiade": "الألعاب الجامعية الصيفية",
    "summer world university games": "ألعاب الجامعات العالمية الصيفية",
    "the universiade": "الألعاب الجامعية",
    "universiade": "الألعاب الجامعية",
    "winter olympics": "الألعاب الأولمبية الشتوية",
    "winter universiade": "الألعاب الجامعية الشتوية",
    "winter world university games": "ألعاب الجامعات العالمية الشتوية",
    "world championships": "بطولات العالم",
    "youth olympic": "الألعاب الأولمبية الشبابية",
    "youth olympics": "الألعاب الأولمبية الشبابية",
    "youth olympics games": "الألعاب الأولمبية الشبابية",
    "all-africa games": "ألعاب عموم إفريقيا",
    "east african games": "الألعاب الإفريقية الشرقية",
    "east all-africa games": "ألعاب عموم إفريقيا الشرقية",
    "east asian games": "الألعاب الآسيوية الشرقية",
    "east central american games": "ألعاب أمريكا الوسطى الشرقية",
    "east commonwealth games": "ألعاب الكومنولث الشرقية",
    "east deaflympic games": "ألعاب ديفلمبياد الشرقية",
    "east european youth olympic": "الألعاب الأولمبية الشبابية الأوروبية الشرقية",
    "east european youth olympic winter": "الألعاب الأولمبية الشبابية الأوروبية الشتوية الشرقية",
    "east jeux de la francophonie": "الألعاب الفرانكوفونية الشرقية",
    "east olympic games": "الألعاب الأولمبية الشرقية",
    "east olympics": "الألعاب الأولمبية الشرقية",
    "east paralympics games": "الألعاب البارالمبية الشرقية",
    "east south american games": "ألعاب أمريكا الجنوبية الشرقية",
    "east universiade": "الألعاب الجامعية الشرقية",
    "east world games": "دورة الألعاب العالمية الشرقية",
    "east youth olympic games": "الألعاب الأولمبية الشبابية الشرقية",
    "east youth olympics": "الألعاب الأولمبية الشبابية الشرقية",
    "jeux de la francophonie": "الألعاب الفرانكوفونية",
    "olympic games": "الألعاب الأولمبية",
    "olympics": "الألعاب الأولمبية",
    "paralympics games": "الألعاب البارالمبية",
    "summer african games": "الألعاب الإفريقية الصيفية",
    "summer all-africa games": "ألعاب عموم إفريقيا الصيفية",
    "summer asian games": "الألعاب الآسيوية الصيفية",
    "summer central american games": "ألعاب أمريكا الوسطى الصيفية",
    "summer commonwealth games": "ألعاب الكومنولث الصيفية",
    "summer deaflympic games": "ألعاب ديفلمبياد الصيفية",
    "summer european youth olympic": "الألعاب الأولمبية الشبابية الأوروبية الصيفية",
    "summer european youth olympic winter": "الألعاب الأولمبية الشبابية الأوروبية الشتوية الصيفية",
    "summer jeux de la francophonie": "الألعاب الفرانكوفونية الصيفية",
    "summer olympic games": "الألعاب الأولمبية الصيفية",
    "summer paralympics games": "الألعاب البارالمبية الصيفية",
    "summer south american games": "ألعاب أمريكا الجنوبية الصيفية",
    "summer world games": "دورة الألعاب العالمية الصيفية",
    "summer youth olympic games": "الألعاب الأولمبية الشبابية الصيفية",
    "summer youth olympics": "الألعاب الأولمبية الشبابية الصيفية",
    "west african games": "الألعاب الإفريقية الغربية",
    "west all-africa games": "ألعاب عموم إفريقيا الغربية",
    "west asian games": "الألعاب الآسيوية الغربية",
    "west central american games": "ألعاب أمريكا الوسطى الغربية",
    "west commonwealth games": "ألعاب الكومنولث الغربية",
    "west deaflympic games": "ألعاب ديفلمبياد الغربية",
    "west european youth olympic": "الألعاب الأولمبية الشبابية الأوروبية الغربية",
    "west european youth olympic winter": "الألعاب الأولمبية الشبابية الأوروبية الشتوية الغربية",
    "west jeux de la francophonie": "الألعاب الفرانكوفونية الغربية",
    "west olympic games": "الألعاب الأولمبية الغربية",
    "west olympics": "الألعاب الأولمبية الغربية",
    "west paralympics games": "الألعاب البارالمبية الغربية",
    "west south american games": "ألعاب أمريكا الجنوبية الغربية",
    "west universiade": "الألعاب الجامعية الغربية",
    "west world games": "دورة الألعاب العالمية الغربية",
    "west youth olympic games": "الألعاب الأولمبية الشبابية الغربية",
    "west youth olympics": "الألعاب الأولمبية الشبابية الغربية",
    "winter african games": "الألعاب الإفريقية الشتوية",
    "winter all-africa games": "ألعاب عموم إفريقيا الشتوية",
    "winter asian games": "الألعاب الآسيوية الشتوية",
    "winter central american games": "ألعاب أمريكا الوسطى الشتوية",
    "winter commonwealth games": "ألعاب الكومنولث الشتوية",
    "winter deaflympic games": "ألعاب ديفلمبياد الشتوية",
    "winter european youth olympic": "الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "winter european youth olympic winter": "الألعاب الأولمبية الشبابية الأوروبية الشتوية الشتوية",
    "winter jeux de la francophonie": "الألعاب الفرانكوفونية الشتوية",
    "winter olympic games": "الألعاب الأولمبية الشتوية",
    "winter paralympics games": "الألعاب البارالمبية الشتوية",
    "winter south american games": "ألعاب أمريكا الجنوبية الشتوية",
    "winter world games": "دورة الألعاب العالمية الشتوية",
    "winter youth olympic games": "الألعاب الأولمبية الشبابية الشتوية",
    "winter youth olympics": "الألعاب الأولمبية الشبابية الشتوية",
    "world games": "دورة الألعاب العالمية",
    "youth olympic games": "الألعاب الأولمبية الشبابية",
}


@pytest.mark.parametrize("category, expected", main_data.items(), ids=main_data.keys())
@pytest.mark.fast
def test_resolve_countries_names_medalists(category: str, expected: str) -> None:
    """
    pytest tests/new_resolvers/countries_names_resolvers/countries_names_medalists/test_countries_names_medalists.py::test_resolve_countries_names_medalists
    """
    label = resolve_countries_names_medalists(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", summer_winter_tabs.items(), ids=summer_winter_tabs.keys())
@pytest.mark.fast
def test_summer_winter_tabs(category: str, expected: str) -> None:
    label = resolve_countries_names_medalists(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", summer_winter_games.items(), ids=summer_winter_games.keys())
@pytest.mark.fast
def test_summer_winter_games(category: str, expected: str) -> None:
    label = resolve_countries_names_medalists(category)
    assert label == expected


TEMPORAL_CASES = [
    ("test_resolve_countries_names_medalists", main_data, resolve_countries_names_medalists),
    ("test_summer_winter_tabs", summer_winter_tabs, resolve_countries_names_medalists),
    ("test_summer_winter_games", summer_winter_games, resolve_countries_names_medalists),
]


@pytest.mark.parametrize("name,data, callback", TEMPORAL_CASES)
@pytest.mark.dump
def test_all_dump(name: str, data: dict[str, str], callback: Callable) -> None:
    expected, diff_result = one_dump_test(data, callback)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""
Template-based category label generation.

This module provides functionality to generate Arabic category labels
by matching English category names against predefined templates based
on suffixes and prefixes.
"""

import functools

from ..helps import logger
from ..new_resolvers.reslove_all import new_resolvers_all
from ..time_resolvers.time_to_arabic import convert_time_to_arabic
from ..translations import get_from_pf_keys2
from . import sport_lab_suffixes, team_work, with_years_bot
from .films_and_others_bot import te_films
from .ma_bots import ye_ts_bot
from .make_bots.bot_2018 import get_pop_All_18
from .make_bots.ends_keys import combined_suffix_mappings
from .matables_bots.table1_bot import get_KAKO
from .o_bots import parties_bot, univer
from .o_bots.peoples_resolver import work_peoples

pp_start_with = {
    "wikipedia categories named after": "تصنيفات سميت بأسماء {}",
    "candidates for president of": "مرشحو رئاسة {}",
    # "candidates in president of" : "مرشحو رئاسة {}",
    "candidates-for": "مرشحو {}",
    # "candidates for" : "مرشحو {}",
    "categories named afters": "تصنيفات سميت بأسماء {}",
    "scheduled": "{} مقررة",
    # "defunct" : "{} سابقة",
}


def _resolve_label(label: str) -> str:
    """Try multiple resolution strategies for a label.

    Args:
        label: The label to resolve

    Returns:
        Resolved Arabic label or empty string
    """
    resolved_label = (
        new_resolvers_all(label)
        or get_from_pf_keys2(label)
        or get_pop_All_18(label)
        or te_films(label)
        or sport_lab_suffixes.get_teams_new(label)
        or parties_bot.get_parties_lab(label)
        or team_work.Get_team_work_Club(label)
        or univer.te_universities(label)
        or work_peoples(label)
        or get_KAKO(label)
        or convert_time_to_arabic(label)
        or get_pop_All_18(label)
        or with_years_bot.Try_With_Years(label)
        or ye_ts_bot.translate_general_category(label, fix_title=False)
        or ""
    )
    return resolved_label


def create_label_from_prefix(input_label):
    template_label = ""

    for prefix, format_template in pp_start_with.items():
        if input_label.startswith(prefix.lower()):
            remaining_label = input_label[len(prefix) :]

            resolved_label = _resolve_label(remaining_label)
            logger.info(f'>>>><<lightblue>> Work_ Templates :"{input_label}", {remaining_label=}')

            if resolved_label:
                logger.info(f'>>>><<lightblue>> Work_ Templates.startswith prefix("{prefix}"), {resolved_label=}')
                template_label = format_template.format(resolved_label)
                logger.info(f">>>> {template_label=}")
                break
    return template_label


def create_label_from_suffix(input_label):
    template_label = ""

    # Try suffix matching - more efficient iteration
    for suffix, format_template in combined_suffix_mappings.items():
        if input_label.endswith(suffix.lower()):
            base_label = input_label[: -len(suffix)]
            logger.info(f'>>>><<lightblue>> Work_ Templates.endswith suffix("{suffix}"), {base_label=}')

            resolved_label = _resolve_label(base_label)
            logger.info(f'>>>><<lightblue>> Work_ Templates :"{input_label}", {base_label=}')

            if resolved_label:
                logger.info(f'>>>><<lightblue>> Work_ Templates.endswith suffix("{suffix}"), {resolved_label=}')
                template_label = format_template.format(resolved_label)
                logger.info(f">>>> {template_label=}")
                break

    return template_label


@functools.lru_cache(maxsize=10000)
def Work_Templates(input_label: str) -> str:
    """ """
    input_label = input_label.lower().strip()
    logger.info(f">> ----------------- start Work_ Templates ----------------- {input_label=}")
    data = {
        "sports leagues": "دوريات رياضية",
    }
    template_label = (
        data.get(input_label) or create_label_from_suffix(input_label) or create_label_from_prefix(input_label)
    )

    logger.info(">> ----------------- end Work_ Templates ----------------- ")
    return template_label



#
import pytest

from ArWikiCats import resolve_arabic_category_label

data = {
    "Category:AFC Bournemouth-related lists": "z",
    "Category:Annam (French protectorate)": "z",
    "Category:Battles involving al-Shabaab (militant group)": "z",
    "Category:Bison herds": "z",
    "Category:CD Vitoria footballers": "z",
    "Category:Cenotaphs": "z",
    "Category:Copa Sudamericana–winning players": "z",
    "Category:Crosses by function": "z",
    "Category:Cúcuta Deportivo footballers": "z",
    "Category:Divisiones Regionales de Fútbol players": "z",
    "Category:Duck as food": "z",
    "Category:EC Granollers players": "z",
    "Category:Electricity ministers": "z",
    "Category:Ethnic Somali people": "z",
    "Category:Flora listed on CITES Appendix II": "z",
    "Category:Fula clans": "z",
    "Category:Fula history": "z",
    "Category:GIGN missions": "z",
    "Category:Gujarat Sultanate mosques": "z",
    "Category:Helicopter attacks": "z",
    "Category:Henry Benedict Stuart": "z",
    "Category:HornAfrik Media Inc": "z",
    "Category:Hussain Ahmad Madani": "z",
    "Category:Lake fish of North America": "z",
    "Category:Lakes of Cochrane District": "z",
    "Category:Memorial crosses": "z",
    "Category:Monotypic Tetragnathidae genera": "z",
    "Category:Monuments of National Importance in Gujarat": "z",
    "Category:Nigerian Fula people": "z",
    "Category:Operations involving French special forces": "z",
    "Category:Pahlavi architecture": "z",
    "Category:Pan-Africanist political parties in Africa": "z",
    "Category:Parliamentary elections in Somalia": "z",
    "Category:People from Gopalganj District, Bangladesh": "z",
    "Category:People with sexual sadism disorder": "z",
    "Category:Ports and marine ministers of Somalia": "z",
    "Category:Presidents of Khatumo": "z",
    "Category:Primera Federación players": "z",
    "Category:Prisoners sentenced to life imprisonment by Slovakia": "z",
    "Category:Prodidominae": "z",
    "Category:Royal monuments": "z",
    "Category:Rõuge Parish": "z",
    "Category:SD Eibar C players": "z",
    "Category:Salvelinus": "z",
    "Category:Sculptures by Antonio Canova": "z",
    "Category:Sculptures of angels": "z",
    "Category:Shia mosques in Iran": "z",
    "Category:Skardu District": "z",
    "Category:Slovak prisoners sentenced to life imprisonment": "z",
    "Category:Socialism in the Gambia": "z",
    "Category:Somali Youth League politicians": "z",
    "Category:Syrian individuals subject to United Kingdom sanctions": "z",
    "Category:Syrian individuals subject to the European Union sanctions": "z",
    "Category:Taxa named by Anton Ausserer": "z",
    "Category:Theraphosidae genera": "z",
    "Category:Tongariro National Park": "z",
    "Category:Tram transport in Europe": "z",
    "Category:Women's rights in Slovakia": "z",
}

data_0 = {}


@pytest.mark.parametrize("category, expected", data_0.items(), ids=data_0.keys())
@pytest.mark.skip2
def test_empty(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected



"""
Tests
"""

import pytest

from ArWikiCats.main_processers.event_lab_bot import event_Lab

data = {
    "category:air force navigational boxes": "تصنيف:صناديق تصفح قوات جوية",
    "category:action films by genre": "تصنيف:أفلام حركة حسب النوع الفني",
    "category:africanamerican history by state": "تصنيف:تاريخ أمريكي إفريقي حسب الولاية",
    "category:airlines by dependent territory": "تصنيف:شركات طيران حسب الأقاليم التابعة",
    "category:ambassadors by mission country": "تصنيف:سفراء حسب بلد البعثة",
    "category:american culture by state": "تصنيف:ثقافة أمريكية حسب الولاية",
    "category:animals by year of formal description": "تصنيف:حيوانات حسب سنة الوصف",
    "category:athletics in the summer universiade navigational boxes": "تصنيف:صناديق تصفح ألعاب القوى في الألعاب الجامعية الصيفية",
    "category:bridges in wales by type": "تصنيف:جسور في ويلز حسب الفئة",
    "category:celtic mythology in popular culture": "تصنيف:أساطير كلتية في الثقافة الشعبية",
    "category:comics set in 1st century bc": "تصنيف:قصص مصورة تقع أحداثها في القرن 1 ق م",
    "category:decades in oklahoma": "تصنيف:عقود في أوكلاهوما",
    "category:destroyed churches by country": "تصنيف:كنائس مدمرة حسب البلد",
    "category:dinosaurs in video games": "تصنيف:ديناصورات في ألعاب فيديو",
    "category:editorial cartoonists from northern ireland": "تصنيف:محررون كارتونيون من أيرلندا الشمالية",
    "category:environment of united states by state or territory": "تصنيف:بيئة الولايات المتحدة حسب الولاية أو الإقليم",
    "category:fantasy films by genre": "تصنيف:أفلام فانتازيا حسب النوع الفني",
    "category:figure skaters in 2002 winter olympics": "تصنيف:متزلجون فنيون في الألعاب الأولمبية الشتوية 2002",
    "category:films by movement": "تصنيف:أفلام حسب الحركة",
    "category:golfers from massachusetts": "تصنيف:لاعبو غولف من ماساتشوستس",
    "category:historic trails and roads in the united states by state": "تصنيف:طرق وممرات تاريخية في الولايات المتحدة حسب الولاية",
    "category:international women's basketball competitions hosted by cuba": "تصنيف:منافسات كرة سلة دولية للسيدات استضافتها كوبا",
    "category:languages of cayman islands": "تصنيف:لغات جزر كايمان",
    "category:multi-sport events in yemen": "تصنيف:أحداث رياضية متعددة في اليمن",
    "category:parks in the roman empire": "تصنيف:متنزهات في الإمبراطورية الرومانية",
}


@pytest.mark.parametrize("text, expected", data.items(), ids=data.keys())
def test_basic_cases(text: str, expected: str) -> None:
    result = event_Lab(text)
    assert result == expected


@pytest.mark.fast
def test_event_lab() -> None:
    # Test with a basic input
    result = event_Lab("test event")
    assert isinstance(result, str)

    # Test with different input
    result_various = event_Lab("sports event")
    assert isinstance(result_various, str)

    # Test with empty string
    result_empty = event_Lab("")
    assert isinstance(result_empty, str)


# ---------------------------------------------------------------------------
# 1) Direct label via resolve_squads_labels_and_templates
# ---------------------------------------------------------------------------


@pytest.mark.fast
def test_event_lab_direct_lab2() -> None:
    result = event_Lab("Category:German footballers")
    assert result == "تصنيف:لاعبو كرة قدم ألمان"


# ---------------------------------------------------------------------------
# 2) Episodes branch + SEO fallback (list_of_cat used, no other labels)
# ---------------------------------------------------------------------------


@pytest.mark.fast
def test_event_lab_episodes_branch_with_seo_fallback() -> None:
    result = event_Lab("Category:Game_of_Thrones_(season_1)_episodes")
    assert result == "تصنيف:حلقات صراع العروش الموسم 1"


# ---------------------------------------------------------------------------
# 3) Templates branch + SEO fallback
# ---------------------------------------------------------------------------


@pytest.mark.fast
def test_event_lab_templates_branch_with_seo_fallback() -> None:
    result = event_Lab("Category:Association_football_templates")

    assert result == "تصنيف:قوالب كرة القدم"


# ---------------------------------------------------------------------------
# 4) get_list_of_and_cat3 footballers + Get_country2 special branch
# ---------------------------------------------------------------------------


@pytest.mark.fast
def test_event_lab_footballers_country_special_case() -> None:
    result = event_Lab("Category:Ethiopian_basketball_players")

    assert result == "تصنيف:لاعبو كرة سلة إثيوبيون"


# ---------------------------------------------------------------------------
# 5) General translation fallback via ye_ts_bot.translate_general_category
# ---------------------------------------------------------------------------


@pytest.mark.fast
def test_event_lab_general_translate_category_fallback() -> None:
    result = event_Lab("Unknown Category For Testing")

    assert result == ""


# ---------------------------------------------------------------------------
# 6) Cricketers / cricket captains branch
# ---------------------------------------------------------------------------


@pytest.mark.fast
def test_event_lab_cricketers_country_mapping() -> None:
    result = event_Lab("Category:Indian cricketers")

    # Expected: "لاعبو كريكت من الهند" with تصنيف: prefix
    assert result == "تصنيف:لاعبو كريكت هنود"



"""Regional translation tables used across the geo modules."""

from __future__ import annotations

from ...helps import len_print
from ..utils.json_dir import open_json_file


def load_regions_data(data: dict[str, str]) -> dict[str, str]:
    ALGERIA_PROVINCE = data.get("ALGERIA_PROVINCE", {})
    ECUADOR_PROVINCE = data.get("ECUADOR_PROVINCE", {})
    LEGACY_UK_COUNTY = data.get("LEGACY_UK_COUNTY", {})
    UK_COUNTY = data.get("UK_COUNTY", {})
    SRI_LANKA_DISTRICT = data.get("SRI_LANKA_DISTRICT", {})
    VENEZUELA_STATE = data.get("VENEZUELA_STATE", {})
    PERU_REGION = data.get("PERU_REGION", {})

    PRIMARY_REGION = data.get("PRIMARY_REGION", {})

    index_labels: dict[str, str] = PRIMARY_REGION | LEGACY_UK_COUNTY | UK_COUNTY

    for region_name, region_label in PERU_REGION.items():
        index_labels[region_name] = region_label
        index_labels[f"{region_name} region"] = f"إقليم {region_label}"
        index_labels[f"{region_name} province"] = f"مقاطعة {region_label}"
        index_labels[f"{region_name} district"] = f"مديرية {region_label}"

    for district_name, district_label in SRI_LANKA_DISTRICT.items():
        index_labels[district_name] = district_label
        index_labels[f"{district_name} district"] = f"مديرية {district_label}"

    for province_name, province_label in ALGERIA_PROVINCE.items():
        index_labels[province_name] = province_label
        index_labels[f"{province_name} province"] = f"ولاية {province_label}"

    for state_name, state_label in VENEZUELA_STATE.items():
        index_labels[state_name] = state_label
        index_labels[f"{state_name} (state)"] = f"ولاية {state_label}"

    for province_name, province_label in ECUADOR_PROVINCE.items():
        index_labels[province_name] = province_label
        index_labels[f"{province_name} province"] = f"مقاطعة {province_label}"

    return index_labels


data = open_json_file("geography/regions.json") or {}
MAIN_REGION_TRANSLATIONS = load_regions_data(data)

__all__ = [
    "MAIN_REGION_TRANSLATIONS",
]

len_print.data_len(
    "regions.py",
    {
        "MAIN_REGION_TRANSLATIONS": MAIN_REGION_TRANSLATIONS,
    },
)



#!/usr/bin/python3
"""
!
"""

import functools
import re
from typing import Pattern

from ..helps import logger
from ..new_resolvers.reslove_all import new_resolvers_all
from ..time_resolvers.time_to_arabic import convert_time_to_arabic
from ..translations import WORD_AFTER_YEARS, change_numb_to_word, get_from_pf_keys2
from . import sport_lab_suffixes, team_work
from .films_and_others_bot import te_films
from .ma_bots.ye_ts_bot import translate_general_category
from .make_bots.bot_2018 import get_pop_All_18
from .make_bots.reg_lines import RE1_compile, RE2_compile, RE33_compile, re_sub_year
from .matables_bots.data import Add_in_table
from .matables_bots.table1_bot import get_KAKO
from .o_bots import parties_bot, univer
from .o_bots.peoples_resolver import work_peoples

# Precompiled Regex Patterns
REGEX_SUB_YEAR = re.compile(re_sub_year, re.IGNORECASE)

known_bodies = {
    # "term of the Iranian Majlis" : "المجلس الإيراني",
    "iranian majlis": "المجلس الإيراني",
    "united states congress": "الكونغرس الأمريكي",
}


arabic_labels_preceding_year = [
    # لإضافة "في" بين البداية والسنة في تصنيفات مثل :
    # tab[Category:1900 rugby union tournaments for national teams] = "تصنيف:بطولات اتحاد رجبي للمنتخبات الوطنية 1900"
    "كتاب بأسماء مستعارة",
    "بطولات اتحاد رجبي للمنتخبات الوطنية",
]

pattern_str = r"^(\d+)(th|nd|st|rd) (%s)$" % "|".join(known_bodies.keys())
_political_terms_pattern = re.compile(pattern_str, re.IGNORECASE)


@functools.lru_cache(maxsize=10000)
def wrap_lab_for_country2(country: str) -> str:
    """
    Retrieve laboratory information for a specified country.
    """

    country2 = country.lower().strip()

    resolved_label = (
        new_resolvers_all(country2)
        or get_from_pf_keys2(country2)
        or get_pop_All_18(country2)
        or te_films(country2)
        or sport_lab_suffixes.get_teams_new(country2)
        or parties_bot.get_parties_lab(country2)
        or team_work.Get_team_work_Club(country2)
        or univer.te_universities(country2)
        or work_peoples(country2)
        or get_KAKO(country2)
        or convert_time_to_arabic(country2)
        or get_pop_All_18(country2)
        or ""
    )
    logger.info(f'>> wrap_lab_for_country2 "{country2}": label: {resolved_label}')

    return resolved_label


def _handle_political_terms(category_text: str) -> str:
    """Handles political terms like 'united states congress'."""
    # كونغرس
    # cs = re.match(r"^(\d+)(th|nd|st|rd) united states congress", category_text)
    if match := _political_terms_pattern.match(category_text):
        ordinal_number = match.group(1)
        body_key = match.group(3)
        body_label = known_bodies[body_key]
        ordinal_label = change_numb_to_word.get(ordinal_number, f"الـ{ordinal_number}")
        label = f"{body_label} {ordinal_label}"
        logger.debug(f">>> _handle_political_terms lab ({label}), country: ({category_text})")
        return label
    return ""


def _handle_year_at_start(category_text: str) -> str:
    """Handles cases where the year is at the start of the string."""
    label = ""
    year = REGEX_SUB_YEAR.sub(r"\g<1>", category_text)
    if year == category_text or not year:
        return ""

    remainder = category_text[len(year) :].strip().lower()
    logger.debug(f">>> _handle_year_at_start: {year=}, suffix:{remainder}")

    remainder_label = ""
    if remainder in WORD_AFTER_YEARS:
        remainder_label = WORD_AFTER_YEARS[remainder]

    if not remainder_label:
        remainder_label = (
            new_resolvers_all(remainder)
            or get_from_pf_keys2(remainder)
            or get_KAKO(remainder)
            or translate_general_category(remainder, fix_title=False)
            or wrap_lab_for_country2(remainder)
            or ""
        )

    if not remainder_label:
        return ""

    separator = " "

    if remainder_label.strip() in arabic_labels_preceding_year:
        logger.debug("arabic_labels_preceding_year Add في to arlabel sus.")
        separator = " في "

    elif remainder in Add_in_table:
        logger.debug("a<<lightblue> > > > > > Add في to suf")
        separator = " في "

    label = remainder_label + separator + year
    logger.debug(f'>>>>>> Try With Years new lab2  "{label}" ')

    return label


def _handle_year_at_end(
    category_text: str,
    compiled_year_pattern: Pattern[str],
    compiled_range_pattern: Pattern[str],
) -> str:
    """Handles cases where the year is at the end of the string."""
    year_at_end_label = compiled_year_pattern.sub(r"\g<1>", category_text.strip())

    range_match = compiled_range_pattern.match(category_text)

    if range_match:
        year_at_end_label = compiled_range_pattern.sub(r"\g<1>", category_text.strip())
        year_at_end_label = compiled_range_pattern.sub(r"\g<1>", category_text.strip())

    # if RE4:
    # year2 = "موسم " + RE4_compile.sub(r"\g<1>", country.strip())

    if year_at_end_label == category_text or not year_at_end_label:
        return ""

    formatted_year_label = year_at_end_label
    logger.debug(f">>> _handle_year_at_end: year2:{year_at_end_label}")
    remainder = category_text[: -len(year_at_end_label)]

    remainder_label = (
        new_resolvers_all(remainder)
        or translate_general_category(remainder, fix_title=False)
        or wrap_lab_for_country2(remainder)
        or ""
    )
    if "–present" in formatted_year_label:
        formatted_year_label = formatted_year_label.replace("–present", "–الآن")

    if remainder_label:
        label = f"{remainder_label} {formatted_year_label}"
        logger.debug(f'>>>>>> Try With Years new lab4  "{label}" ')
        return label
    return ""


@functools.lru_cache(maxsize=None)
def Try_With_Years(category_text: str) -> str:
    """Retrieve a formatted label for a given country based on its historical
    context.

    This function processes the input country string to extract relevant
    year information and formats it according to predefined rules. It checks
    for specific patterns in the input string, such as congressional terms
    or year ranges, and returns a corresponding label. If the input does not
    match any known patterns, an empty string is returned. The function also
    caches results for efficiency.

    Args:
        category_text (str): The name of the country or a related term that may include year
            information.

    Returns:
        str: A formatted label that includes the country name and associated year
            information,
        or an empty string if no valid information is found.
    """
    logger.debug(f">>> Try With Years country ({category_text})")
    # pop_final_Without_Years

    label = ""
    category_text = category_text.strip()

    if category_text.isdigit():
        return category_text

    category_text = category_text.replace("−", "-")

    if label := _handle_political_terms(category_text):
        return label

    year_at_start = RE1_compile.match(category_text)
    year_at_end = RE2_compile.match(category_text)
    # Category:American Soccer League (1933–83)
    year_at_end2 = RE33_compile.match(category_text)
    # RE4 = RE4_compile.match(category_text)

    if not year_at_start and not year_at_end and not year_at_end2:  # and not RE4
        return ""

    label = _handle_year_at_start(category_text)

    if not label:
        label = _handle_year_at_end(category_text, RE2_compile, RE33_compile)

    if label:
        logger.debug(f'>>>>>> Try With Years lab2 "{label}" ')

    return label


def Try_With_Years2(category_r) -> str:
    """ """
    cat3 = category_r.lower().replace("category:", "").strip()

    logger.info(f'<<lightred>>>>>> category33:"{cat3}" ')

    # TODO: THIS NEED REVIEW
    # Reject strings that contain common English prepositions
    blocked = ("in", "of", "from", "by", "at")
    if any(f" {word} " in cat3.lower() for word in blocked):
        return ""

    category_lab = ""
    if re.sub(r"^\d", "", cat3) != cat3:
        category_lab = Try_With_Years(cat3)

    return category_lab



"""
Build comprehensive gendered job label dictionaries.
"""

from __future__ import annotations

from typing import Dict, Mapping

from ...helps import len_print
from ..sports.Sport_key import SPORTS_KEYS_FOR_JOBS
from .jobs_data_basic import RELIGIOUS_KEYS_PP
from .jobs_defs import GenderedLabel, GenderedLabelMap, combine_gender_labels

FEMALE_JOBS_SPORTS: Dict[str, str] = {}

for job_key, arabic_label in SPORTS_KEYS_FOR_JOBS.items():
    # Provide a category entry for women's players to preserve the legacy API.
    FEMALE_JOBS_SPORTS[f"women's {job_key.lower()} players"] = f"لاعبات {arabic_label} نسائية"


FEMALE_JOBS_BASE: Dict[str, str] = {
    "nuns": "راهبات",
    "deafblind actresses": "ممثلات صم ومكفوفات",
    "deaf actresses": "ممثلات صم",
    "actresses": "ممثلات",
    "princesses": "أميرات",
    "video game actresses": "ممثلات ألعاب فيديو",
    "musical theatre actresses": "ممثلات مسرحيات موسيقية",
    "television actresses": "ممثلات تلفزيون",
    "stage actresses": "ممثلات مسرح",
    "voice actresses": "ممثلات أداء صوتي",
    "women in business": "سيدات أعمال",
    "women in politics": "سياسيات",
    "lesbians": "سحاقيات",
    "businesswomen": "سيدات أعمال",
    "film actresses": "ممثلات أفلام",
    "pornographic film actresses": "ممثلات أفلام إباحية",
    "radio actresses": "ممثلات راديو",
    "silent film actresses": "ممثلات أفلام صامتة",
}


RELIGIOUS_ROLE_LABELS_FEMALES: GenderedLabelMap = {
    "nuns": "راهبات",
}


def _build_religious_job_labels(
    religions: Mapping[str, GenderedLabel],
    roles: dict[str, str],
) -> GenderedLabelMap:
    """
    Generate gendered labels for religious roles.
    """

    combined_roles: GenderedLabelMap = {}
    for role_key, role_female_labels in roles.items():
        if not role_key or not role_female_labels:
            continue
        combined_roles[role_key] = role_female_labels

        for religion_key, religion_labels in religions.items():
            if not religion_key or not religion_labels:
                continue
            females_label = combine_gender_labels(role_female_labels, religion_labels["females"])

            if females_label:
                combined_roles[f"{religion_key} {role_key}"] = females_label

    return combined_roles


FEMALE_JOBS_BASE_EXTENDED = _build_religious_job_labels(RELIGIOUS_KEYS_PP, RELIGIOUS_ROLE_LABELS_FEMALES)

short_womens_jobs = FEMALE_JOBS_BASE | FEMALE_JOBS_BASE_EXTENDED | FEMALE_JOBS_SPORTS

FEMALE_JOBS_BASE_EXTENDED.update(FEMALE_JOBS_BASE)

short_womens_jobs["sportswomen"] = "رياضيات"

__all__ = [
    "FEMALE_JOBS_BASE_EXTENDED",
    "short_womens_jobs",
]

len_print.data_len(
    "jobs_womens.py",
    {
        "FEMALE_JOBS_BASE_EXTENDED": FEMALE_JOBS_BASE_EXTENDED,
        "short_womens_jobs": short_womens_jobs,
        "FEMALE_JOBS_SPORTS": FEMALE_JOBS_SPORTS,
    },
)
